@@ -1,18 +1,18 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import csv
-from io import StringIO
+from io import BytesIO, TextIOWrapper
 
 from sql import Table
 from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
 from trytond.config import config
-from trytond.pool import PoolMeta, Pool
+from trytond.model import ModelStorage, ModelView, fields
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
-from trytond.wizard import Wizard, StateView, StateTransition, Button
-from trytond.model import ModelView, ModelStorage, fields
+from trytond.wizard import Button, StateTransition, StateView, Wizard
 
 OPENING_CODE = config.get('account_fr', 'fec_opening_code', default="OUV")
 OPENING_NAME = config.get(
@@ -20,6 +20,36 @@ OPENING_NAME = config.get(
 OPENING_NUMBER = config.get('account_fr', 'fec_opening_number', default="0")
 
 
+class AccountTemplate(metaclass=PoolMeta):
+    __name__ = 'account.account.template'
+
+    @classmethod
+    def __register__(cls, module_name):
+        cursor = Transaction().connection.cursor()
+        model_data = Table('ir_model_data')
+
+        # Migration from 6.0: rename ids
+        if module_name == 'account_fr':
+            for old_id, new_id in (
+                    ('fr_pcg_pay', '4011'),
+                    ('fr_pcg_recv', '4111'),
+                    ('fr_pcg_cash', '512'),
+                    ('fr_pcg_expense', '607'),
+                    ):
+                cursor.execute(*model_data.select(model_data.id,
+                        where=(model_data.fs_id == new_id)
+                        & (model_data.module == module_name)))
+                if cursor.fetchone():
+                    continue
+                cursor.execute(*model_data.update(
+                        columns=[model_data.fs_id],
+                        values=[new_id],
+                        where=(model_data.fs_id == old_id)
+                        & (model_data.module == module_name)))
+
+        super().__register__(module_name)
+
+
 class TaxTemplate(metaclass=PoolMeta):
     __name__ = 'account.tax.template'
 
@@ -56,6 +86,22 @@ class TaxTemplate(metaclass=PoolMeta):
         super(TaxTemplate, cls).__register__(module_name)
 
 
+class CreateChart(metaclass=PoolMeta):
+    __name__ = 'account.create_chart'
+
+    def default_properties(self, fields):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        defaults = super().default_properties(fields)
+        template_id = ModelData.get_id('account_fr.root')
+        if self.account.account_template.id == template_id:
+            defaults['account_receivable'] = self.get_account(
+                'account_fr.4111')
+            defaults['account_payable'] = self.get_account(
+                'account_fr.4011')
+        return defaults
+
+
 class TaxRuleTemplate(metaclass=PoolMeta):
     __name__ = 'account.tax.rule.template'
 
@@ -97,26 +143,23 @@ class FrFEC(Wizard):
             ])
 
     def transition_generate(self):
-        fec = StringIO()
-        writer = self.get_writer(fec)
+        fec = BytesIO()
+        writer = self.get_writer(
+            TextIOWrapper(fec, encoding='utf-8', write_through=True))
         writer.writerow(self.get_header())
         format_date = self.get_format_date()
         format_number = self.get_format_number()
 
-        def replace_delimiter(c):
+        def convert(c):
             delimiter = writer.dialect.delimiter
-            return (c or '').replace(delimiter, ' ')
-        convert = replace_delimiter
+            return (c or '').replace(delimiter, ' ').replace('\n', ' ')
 
         for row in self.get_start_balance():
             writer.writerow(map(convert, row))
         for line in self.get_lines():
             row = self.get_row(line, format_date, format_number)
             writer.writerow(map(convert, row))
-        value = fec.getvalue()
-        if not isinstance(value, bytes):
-            value = value.encode('utf-8')
-        self.result.file = self.result.__class__.file.cast(value)
+        self.result.file = self.result.__class__.file.cast(fec.getvalue())
         return 'result'
 
     def default_result(self, fields):
@@ -338,7 +381,6 @@ class FrFECStart(ModelView):
             ('fiscalyear', '=', Eval('fiscalyear')),
             ('type', '=', 'adjustment'),
             ],
-        depends=['fiscalyear'],
         help="The period to exclude which contains "
         "the moves to balance non-deferral account")
 
